@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  acuordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -25,6 +30,17 @@
 
 using namespace GammaRay;
 
+ProbeControllerInterface::ProbeControllerInterface(QObject *parent)
+    : QObject(parent)
+{
+    qRegisterMetaType<ObjectId>();
+    qRegisterMetaTypeStreamOperators<ObjectId>();
+    qRegisterMetaType<ToolInfo>();
+    qRegisterMetaTypeStreamOperators<ToolInfo>();
+    qRegisterMetaType<ToolInfos>();
+    qRegisterMetaTypeStreamOperators<ToolInfos>();
+}
+
 ProbeControllerInterface::~ProbeControllerInterface()
 {
 }
