@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,7 +36,6 @@
 #include <QVector>
 
 namespace GammaRay {
-
 class PropertyAdaptor;
 class PropertyData;
 class ObjectInstance;
@@ -51,23 +50,27 @@ public:
 
     void setObject(const ObjectInstance &oi);
 
-    QVariant data(const QModelIndex& index, int role) const Q_DECL_OVERRIDE;
-    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex& parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int rowCount(const QModelIndex& parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QModelIndex parent(const QModelIndex& child) const Q_DECL_OVERRIDE;
-    QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    Qt::ItemFlags flags(const QModelIndex& index) const Q_DECL_OVERRIDE;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    QMap<int, QVariant> itemData(const QModelIndex& index) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    bool setData(const QModelIndex &index, const QVariant &value,
+                 int role = Qt::EditRole) Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QModelIndex parent(const QModelIndex &child) const Q_DECL_OVERRIDE;
+    QModelIndex index(int row, int column,
+                      const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QVariant headerData(int section, Qt::Orientation orientation,
+                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    QMap<int, QVariant> itemData(const QModelIndex &index) const Q_DECL_OVERRIDE;
 
 private:
     void clear();
-    PropertyAdaptor* adaptorForIndex(const QModelIndex &index) const;
+    PropertyAdaptor *adaptorForIndex(const QModelIndex &index) const;
     void addPropertyAdaptor(PropertyAdaptor *adaptor) const;
     QVariant data(PropertyAdaptor *adaptor, const PropertyData &d, int column, int role) const;
-    bool hasLoop(PropertyAdaptor* adaptor, const QVariant &v) const;
+    bool hasLoop(PropertyAdaptor *adaptor, const QVariant &v) const;
     void reloadSubTree(PropertyAdaptor *parentAdaptor, int index);
+    bool isParentEditable(PropertyAdaptor *adaptor) const;
 
 private slots:
     void propertyChanged(int first, int last);
@@ -78,9 +81,9 @@ private slots:
 
 private:
     PropertyAdaptor *m_rootAdaptor;
-    mutable QHash<PropertyAdaptor*, QVector<PropertyAdaptor*> > m_parentChildrenMap;
+    mutable QHash<PropertyAdaptor *, QVector<PropertyAdaptor *> > m_parentChildrenMap;
+    bool m_inhibitAdaptorCreation;
 };
-
 }
 
 #endif // GAMMARAY_AGGREGATEDPROPERTYMODEL_H
