@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,23 +37,21 @@
 #include <QMetaMethod>
 
 namespace GammaRay {
-
-class ObjectMethodModel :
-    public MetaObjectModel<QMetaMethod, &QMetaObject::method,
-                           &QMetaObject::methodCount, &QMetaObject::methodOffset>
+class ObjectMethodModel : public MetaObjectModel<QMetaMethod, &QMetaObject::method,
+                                                 &QMetaObject::methodCount,
+                                                 &QMetaObject::methodOffset>
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit ObjectMethodModel(QObject *parent = 0);
     int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QMap< int, QVariant > itemData(const QModelIndex& index) const Q_DECL_OVERRIDE;
+    QMap< int, QVariant > itemData(const QModelIndex &index) const Q_DECL_OVERRIDE;
 
-  protected:
-    QVariant metaData(const QModelIndex &index,
-                  const QMetaMethod &method, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+protected:
+    QVariant metaData(const QModelIndex &index, const QMetaMethod &method,
+                      int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
     QString columnHeader(int index) const Q_DECL_OVERRIDE;
 };
-
 }
 
 Q_DECLARE_METATYPE(QMetaMethod)
