@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -45,49 +45,49 @@
 
 using namespace GammaRay;
 
-StyleInjector::StyleInjector() : ProcessInjector()
+StyleInjector::StyleInjector()
+    : ProcessInjector()
 {
 }
 
 QString StyleInjector::name() const
 {
-  return QStringLiteral("style");
+    return QStringLiteral("style");
 }
 
-bool StyleInjector::launch(const QStringList &programAndArgs,
-                           const QString &probeDll, const QString &probeFunc,
-                           const QProcessEnvironment &e)
+bool StyleInjector::launch(const QStringList &programAndArgs, const QString &probeDll,
+                           const QString &probeFunc, const QProcessEnvironment &e)
 {
-  auto env = e.isEmpty()? QProcessEnvironment::systemEnvironment() : e;
-  env.insert(QStringLiteral("GAMMARAY_STYLEINJECTOR_PROBEDLL"), probeDll);
-  env.insert(QStringLiteral("GAMMARAY_STYLEINJECTOR_PROBEFUNC"), probeFunc);
+    auto env = e.isEmpty() ? QProcessEnvironment::systemEnvironment() : e;
+    env.insert(QStringLiteral("GAMMARAY_STYLEINJECTOR_PROBEDLL"), probeDll);
+    env.insert(QStringLiteral("GAMMARAY_STYLEINJECTOR_PROBEFUNC"), probeFunc);
 
-  QString qtPluginPath = env.value(QStringLiteral("QT_PLUGIN_PATH"));
-  if (!qtPluginPath.isEmpty()) {
-    qtPluginPath.append(":");
-  }
-  qtPluginPath.append(Paths::currentProbePath());
-  env.insert(QStringLiteral("QT_PLUGIN_PATH"), qtPluginPath);
+    QString qtPluginPath = env.value(QStringLiteral("QT_PLUGIN_PATH"));
+    if (!qtPluginPath.isEmpty())
+        qtPluginPath.append(":");
+    qtPluginPath.append(Paths::currentPluginsPath());
+    env.insert(QStringLiteral("QT_PLUGIN_PATH"), qtPluginPath);
 
-  QStringList args = programAndArgs;
-  args << QStringLiteral("-style") << QStringLiteral("gammaray-injector");
+    QStringList args = programAndArgs;
+    args << QStringLiteral("-style") << QStringLiteral("gammaray-injector");
 
-  return launchProcess(args, env);
+    return launchProcess(args, env);
 }
 
 bool StyleInjector::selfTest()
 {
-#ifdef HAVE_QT_WIDGETS
-  QCoreApplication::addLibraryPath(Paths::currentProbePath());
-  if (!QStyleFactory::keys().contains(QStringLiteral("gammaray-injector"))) {
-    mErrorString = QObject::tr("Injector style plugin is not found in the Qt style "
-                               "plug-in search path or cannot be loaded");
-    return false;
-  }
+#ifndef GAMMARAY_CORE_ONLY_LAUNCHER
+    QCoreApplication::addLibraryPath(Paths::currentPluginsPath());
+    if (!QStyleFactory::keys().contains(QStringLiteral("gammaray-injector"))) {
+        mErrorString = tr("Injector style plugin is not found in the Qt style "
+                          "plug-in search path or cannot be loaded");
+        return false;
+    }
 
-  return true;
+    return true;
 #else
-  mErrorString = QObject::tr("GammaRay was compiled without QtWidget support, style injector is not available.");
-  return false;
+    mErrorString = tr(
+        "GammaRay was compiled without QtWidget support, style injector is not available.");
+    return false;
 #endif
 }
