@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -49,33 +49,28 @@ Q_EXPORT_PLUGIN(SelectionModelInspectorFactory)
 #endif
 
 SelectionModelInspector::SelectionModelInspector(ProbeInterface *probe, QObject *parent)
-  : QObject(parent)
-  , m_current(new QIdentityProxyModel(this))
+    : QObject(parent)
+    , m_current(new QIdentityProxyModel(this))
 {
-  ObjectTypeFilterProxyModel<QItemSelectionModel> *selectionModelProxy =
-    new ObjectTypeFilterProxyModel<QItemSelectionModel>(this);
-  selectionModelProxy->setSourceModel(probe->objectListModel());
-  probe->registerModel(QStringLiteral("com.kdab.GammaRay.SelectionModelsModel"), selectionModelProxy);
+    ObjectTypeFilterProxyModel<QItemSelectionModel> *selectionModelProxy
+        = new ObjectTypeFilterProxyModel<QItemSelectionModel>(this);
+    selectionModelProxy->setSourceModel(probe->objectListModel());
+    probe->registerModel(QStringLiteral(
+                             "com.kdab.GammaRay.SelectionModelsModel"), selectionModelProxy);
 
-  QItemSelectionModel *selectionModel = ObjectBroker::selectionModel(selectionModelProxy);
-  connect(selectionModel, SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-          SLOT(currentChanged(QModelIndex)));
+    QItemSelectionModel *selectionModel = ObjectBroker::selectionModel(selectionModelProxy);
+    connect(selectionModel, SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+            SLOT(currentChanged(QModelIndex)));
 
-  probe->registerModel(QStringLiteral("com.kdab.GammaRay.CurrentSelectionModel"), m_current);
+    probe->registerModel(QStringLiteral("com.kdab.GammaRay.CurrentSelectionModel"), m_current);
 }
 
 void SelectionModelInspector::currentChanged(const QModelIndex &current)
 {
-  QObject *selectionModelObject = current.data(ObjectModel::ObjectRole).value<QObject*>();
-  QItemSelectionModel *selectionModel = qobject_cast<QItemSelectionModel*>(selectionModelObject);
-  if (selectionModel && selectionModel->model()) {
-    m_current->setSourceModel(const_cast<QAbstractItemModel*>(selectionModel->model()));
-  } else {
-    m_current->setSourceModel(0);
-  }
-}
-
-QString SelectionModelInspectorFactory::name() const
-{
-  return tr("Selection Models");
+    QObject *selectionModelObject = current.data(ObjectModel::ObjectRole).value<QObject *>();
+    QItemSelectionModel *selectionModel = qobject_cast<QItemSelectionModel *>(selectionModelObject);
+    if (selectionModel && selectionModel->model())
+        m_current->setSourceModel(const_cast<QAbstractItemModel *>(selectionModel->model()));
+    else
+        m_current->setSourceModel(0);
 }
