@@ -4,9 +4,14 @@
  * This file is part of GammaRay, the Qt application inspection and
  * manipulation tool.
  *
- * Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+ * Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  * Author: Milian Wolff <milian.wolff@kdab.com>
  *
+ * Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+ * accordance with GammaRay Commercial License Agreement provided with the Software.
+ *
+ * Contact info@kdab.com if any conditions of this licensing are not clear to you.
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
@@ -25,19 +30,22 @@
 #ifndef RESOURCEBROWSERCLIENT_H
 #define RESOURCEBROWSERCLIENT_H
 
-#include <common/resourcebrowserinterface.h>
+#include <common/tools/resourcebrowser/resourcebrowserinterface.h>
 
 namespace GammaRay {
-
 class ResourceBrowserClient : public ResourceBrowserInterface
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ResourceBrowserInterface)
-  public:
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ResourceBrowserInterface)
+public:
     explicit ResourceBrowserClient(QObject *parent);
     virtual ~ResourceBrowserClient();
-};
 
+    void downloadResource(const QString &sourceFilePath,
+                          const QString &targetFilePath) Q_DECL_OVERRIDE;
+    void selectResource(const QString &sourceFilePath, int line = -1,
+                        int column = -1) Q_DECL_OVERRIDE;
+};
 }
 
 #endif // RESOURCEBROWSERCLIENT_H
